@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 module Main where
 import Text.CSL.Input.Bibutils (readBiblioString, BibFormat(..))
 import Text.CSL.Reference (Reference(refId), Literal(..))
@@ -11,7 +12,7 @@ import qualified Data.ByteString.Char8 as B8
 import Data.Attoparsec.ByteString.Char8 as Attoparsec
 import qualified Data.Text as T
 import Data.Text.Encoding (encodeUtf8)
-import Data.Aeson.Encode.Pretty (encodePretty', Config(..))
+import Data.Aeson.Encode.Pretty (encodePretty', Config(..), Indent(Spaces), NumberFormat(Generic))
 import System.Console.GetOpt
 import Control.Monad
 import System.IO
@@ -61,8 +62,9 @@ main = do
                  B8.intercalate (B.singleton 10) .
                  map (unescapeTags . toByteString . (:[]))
             else B8.putStrLn . unescapeUnicode . B.concat . BL.toChunks .
-              encodePretty' Config{ confIndent = 2
-                                  , confCompare = compare }
+              encodePretty' Config{ confIndent = Spaces 2
+                                  , confCompare = compare
+                                  , confNumFormat = Generic }
      else toJSONFilter doCites
 
 formatFromExtension :: FilePath -> Maybe BibFormat
@@ -73,6 +75,9 @@ readFormat = go . map toLower
   where go "biblatex" = Just BibLatex
         go "bib"      = Just BibLatex
         go "bibtex"   = Just Bibtex
+        go "json"     = Just Json
+        go "yaml"     = Just Yaml
+#ifdef USE_BIBUTILS
         go "ris"      = Just Ris
         go "endnote"  = Just Endnote
         go "enl"      = Just Endnote
@@ -82,9 +87,8 @@ readFormat = go . map toLower
         go "isi"      = Just Isi
         go "medline"  = Just Medline
         go "copac"    = Just Copac
-        go "json"     = Just Json
         go "mods"     = Just Mods
-        go "yaml"     = Just Yaml
+#endif
         go _          = Nothing
 
 
