@@ -26,11 +26,10 @@ import Data.Monoid (Any(..))
 import Data.Char ( toLower, isDigit, isLetter )
 import Data.Maybe
 import Data.String ( fromString )
-import Text.Pandoc.Definition (Inline(Str, Space, Link), nullAttr)
+import Text.Pandoc.Definition (Inline(Str, Link), nullAttr)
 import Text.Pandoc.Walk (walk)
 import Text.Pandoc.Shared (stringify)
 import qualified Data.Text as T
-import Data.Maybe (isNothing)
 
 import Text.CSL.Eval.Common
 import Text.CSL.Eval.Output
@@ -40,7 +39,7 @@ import Text.CSL.Output.Plain
 import Text.CSL.Reference
 import Text.CSL.Style hiding (Any)
 import Text.CSL.Util ( readNum, last', proc, proc', query, betterThan,
-                       safeRead )
+                       safeRead, isRange )
 
 -- | Produce the output with a 'Layout', the 'EvalMode', a 'Bool'
 -- 'True' if the evaluation happens for disambiguation purposes, the
@@ -175,9 +174,7 @@ evalElement el
                             case numVars of
                               ["number-of-volumes"] -> not $ any (== "1") nums
                               ["number-of-pages"]   -> not $ any (== "1") nums
-                              _ -> any
-                                   (\x -> '-' `elem` x || '\x2013' `elem` x)
-                                   nums
+                              _ -> any isRange nums
                          pluralizeTerm x = x
                      if null res
                         then return []
@@ -204,35 +201,39 @@ evalElement el
                                         , env = (env s)
                                           {names = tail $ names (env s)}}) >> return r
 
-      getVariable f fm s = if isTitleVar s || isTitleShortVar s
-                           then consumeVariable s >> formatTitle s f fm else
-                           case map toLower s of
-                             "year-suffix" -> getStringVar "ref-id" >>= \k  ->
-                                              return . return $ OYearSuf [] k [] fm
-                             "page"        -> getStringVar "page" >>= formatRange fm
-                             "locator"     -> getLocVar >>= formatRange fm . snd
-                             "url"         -> getStringVar "url" >>= \k ->
-                                              if null k then return [] else return [Output [OPan [Link nullAttr [Str k] (k,"")]] fm]
-                             "doi"         -> do d <- getStringVar "doi"
-                                                 let (prefixPart, linkPart) = T.breakOn (T.pack "http") (T.pack (prefix fm))
-                                                 let u = if T.null linkPart
-                                                            then "https://doi.org/" ++ d
-                                                            else T.unpack linkPart ++ d
-                                                 if null d
-                                                    then return []
-                                                    else return [Output [OPan [Link nullAttr [Str (T.unpack linkPart ++ d)] (u, "")]]
-                                                          fm{ prefix = T.unpack prefixPart, suffix = suffix fm }]
-                             "pmid"        -> getStringVar "pmid" >>= \d ->
-                                              if null d
-                                                 then return []
-                                                 else return [Output [OPan [Link nullAttr [Str d] ("http://www.ncbi.nlm.nih.gov/pubmed/" ++ d, "")]] fm]
-                             "pmcid"       -> getStringVar "pmcid" >>= \d ->
-                                              if null d
-                                                 then return []
-                                                 else return [Output [OPan [Link nullAttr [Str d] ("http://www.ncbi.nlm.nih.gov/pmc/articles/" ++ d, "")]] fm]
-                             _             -> gets (env >>> options &&& abbrevs) >>= \(opts,as) ->
-                                              getVar [] (getFormattedValue opts as f fm s) s >>= \r ->
-                                              consumeVariable s >> return r
+      getVariable f fm s
+        | isTitleVar s || isTitleShortVar s =
+             consumeVariable s >> formatTitle s f fm
+        | otherwise =
+             case map toLower s of
+               "year-suffix" -> getStringVar "ref-id" >>= \k  ->
+                                return . return $ OYearSuf [] k [] fm
+               "page"        -> getStringVar "page" >>= formatRange fm
+               "locator"     -> getLocVar >>= formatRange fm . snd
+               "url"         -> getStringVar "url" >>= \k ->
+                                if null k then return [] else return [Output [OPan [Link nullAttr [Str k] (k,"")]] fm]
+               "doi"         -> do d <- getStringVar "doi"
+                                   let (prefixPart, linkPart) = T.breakOn (T.pack "http") (T.pack (prefix fm))
+                                   let u = if T.null linkPart
+                                              then "https://doi.org/" ++ d
+                                              else T.unpack linkPart ++ d
+                                   if null d
+                                      then return []
+                                      else return [Output [OPan [Link nullAttr [Str (T.unpack linkPart ++ d)] (u, "")]]
+                                            fm{ prefix = T.unpack prefixPart, suffix = suffix fm }]
+               "pmid"        -> getStringVar "pmid" >>= \d ->
+                                if null d
+                                   then return []
+                                   else return [Output [OPan [Link nullAttr [Str d] ("http://www.ncbi.nlm.nih.gov/pubmed/" ++ d, "")]] fm]
+               "pmcid"       -> getStringVar "pmcid" >>= \d ->
+                                if null d
+                                   then return []
+                                   else return [Output [OPan [Link nullAttr [Str d] ("http://www.ncbi.nlm.nih.gov/pmc/articles/" ++ d, "")]] fm]
+               _ -> do (opts, as) <- gets (env >>> options &&& abbrevs)
+                       r <- getVar []
+                              (getFormattedValue opts as f fm s) s
+                       consumeVariable s
+                       return r
 
 evalIfThen :: IfThen -> [IfThen] -> [Element] -> State EvalState [Element]
 evalIfThen (IfThen c' m' el') ei e = whenElse (evalCond m' c') (return el') rest
@@ -286,6 +287,8 @@ getFormattedValue o as f fm s val
                       then []
                       else [Output [OPan $ walk value' ys] fm]
     | Just v <- fromValue val :: Maybe String    = (:[]) . flip OStr fm . maybe v id . getAbbr $ value v
+    | Just v <- fromValue val :: Maybe Literal   = (:[]) . flip OStr fm . maybe (unLiteral v) id . getAbbr $ value $ unLiteral v
+    | Just v <- fromValue val :: Maybe Int       = output  fm (if v == 0 then [] else show v)
     | Just v <- fromValue val :: Maybe Int       = output  fm (if v == 0 then [] else show v)
     | Just v <- fromValue val :: Maybe CNum      = if v == 0 then [] else [OCitNum (unCNum v) fm]
     | Just v <- fromValue val :: Maybe [RefDate] = formatDate (EvalSorting emptyCite) [] [] sortDate v
@@ -372,10 +375,10 @@ isNumericString s  = all (\c -> isNumber c || isSpecialChar c) $ words s
 
 isTransNumber, isSpecialChar,isNumber :: String -> Bool
 isTransNumber = all isDigit
-isSpecialChar = all (`elem` "&-,\x2013")
+isSpecialChar = all (`elem` "&-,.\x2013")
 isNumber   cs = case [c | c <- cs
                         , not (isLetter c)
-                        , not (c `elem` "&-,\x2013")] of
+                        , not (c `elem` "&-.,\x2013")] of
                      []  -> False
                      xs  -> all isDigit xs
 
