@@ -12,14 +12,18 @@
 -----------------------------------------------------------------------------
 
 module Text.CSL.Input.Bibtex
-    ( readBibtexInput
-    , readBibtexInputString
+    ( readBibtex
+    , readBibtexString
+    , readBibtexString'
     )
     where
 
 import Text.Parsec hiding (optional, (<|>), many, State)
 import Control.Applicative
-import Text.Pandoc
+import Text.Pandoc (readLaTeX, ReaderOptions(..))
+import Text.Pandoc.Definition
+import Text.Pandoc.Generic (bottomUp)
+import Data.Default (Default(def))
 import Data.List.Split (splitOn, splitWhen, wordsBy)
 import Data.List (intercalate)
 import Data.Maybe
@@ -80,23 +84,33 @@ data Item = Item{ identifier :: String
                 , fields     :: [(String, String)]
                 }
 
-readBibtexInput :: Bool -> FilePath -> IO [Reference]
-readBibtexInput isBibtex f = UTF8.readFile f >>= readBibtexInputString isBibtex
-
-readBibtexInputString :: Bool -> String -> IO [Reference]
-readBibtexInputString isBibtex bibstring = do
+getLangFromEnv :: IO Lang
+getLangFromEnv = do
   env <- getEnvironment
-  let lang = case lookup "LANG" env of
+  return $ case lookup "LANG" env of
                   Just x  -> case splitWhen (\c -> c == '.' || c == '_' || c == '-') x of
                                    (w:z:_)            -> Lang w z
                                    [w] | not (null w) -> Lang w mempty
                                    _                  -> Lang "en" "US"
                   Nothing -> Lang "en" "US"
+
+readBibtex :: Bool -> Bool -> FilePath -> IO [Reference]
+readBibtex isBibtex caseTransform f =
+  UTF8.readFile f >>= readBibtexString isBibtex caseTransform
+
+readBibtexString :: Bool -> Bool -> String -> IO [Reference]
+readBibtexString isBibtex caseTransform contents = do
+  lang <- getLangFromEnv
+  locale <- parseLocale (langToLocale lang)
+  return $ readBibtexString' isBibtex caseTransform lang locale contents
+
+-- pure version of readBibtexString
+readBibtexString' :: Bool -> Bool -> Lang -> Locale -> String -> [Reference]
+readBibtexString' isBibtex caseTransform lang locale bibstring =
   let items = case runParser (bibEntries <* eof) [] "stdin" bibstring of
                    Left err -> error (show err)
                    Right xs -> resolveCrossRefs isBibtex xs
-  locale <- parseLocale (langToLocale lang)
-  return $ mapMaybe (itemToReference lang locale isBibtex) items
+  in  mapMaybe (itemToReference lang locale isBibtex caseTransform) items
 
 type BibParser = Parsec [Char] [(String, String)]
 
@@ -158,7 +172,7 @@ inQuotes = do
                       ) (char '"')
 
 fieldName :: BibParser String
-fieldName = (map toLower) <$> many1 (letter <|> digit <|> oneOf "-_")
+fieldName = (map toLower) <$> many1 (letter <|> digit <|> oneOf "-_:")
 
 isBibtexKeyChar :: Char -> Bool
 isBibtexKeyChar c = isAlphaNum c || c `elem` ".:;?!`'()/*@_+=-[]*"
@@ -743,7 +757,7 @@ resolveKey' (Lang "pt" "PT") k =
        "audiocd"       -> "CD áudio"
        _               -> k
 resolveKey' (Lang "pt" "BR") k =
-    case map toLower k of       
+    case map toLower k of
        -- "candthesis" -> "" -- missing
        "techreport"    -> "relatório técnico"
        "resreport"     -> "relatório de pesquisa"
@@ -816,19 +830,21 @@ resolveKey' (Lang "sv" "SE") k =
 resolveKey' _ k = resolveKey' (Lang "en" "US") k
 
 parseMonth :: String -> String
-parseMonth "jan" = "1"
-parseMonth "feb" = "2"
-parseMonth "mar" = "3"
-parseMonth "apr" = "4"
-parseMonth "may" = "5"
-parseMonth "jun" = "6"
-parseMonth "jul" = "7"
-parseMonth "aug" = "8"
-parseMonth "sep" = "9"
-parseMonth "oct" = "10"
-parseMonth "nov" = "11"
-parseMonth "dec" = "12"
-parseMonth x     = x
+parseMonth s =
+  case map toLower s of
+         "jan" -> "1"
+         "feb" -> "2"
+         "mar" -> "3"
+         "apr" -> "4"
+         "may" -> "5"
+         "jun" -> "6"
+         "jul" -> "7"
+         "aug" -> "8"
+         "sep" -> "9"
+         "oct" -> "10"
+         "nov" -> "11"
+         "dec" -> "12"
+         _     -> s
 
 data BibState = BibState{
            untitlecase     :: Bool
@@ -919,10 +935,11 @@ fixLeadingDash xs = xs
 getOldDates :: String -> Bib [RefDate]
 getOldDates prefix = do
   year' <- fixLeadingDash <$> getRawField (prefix ++ "year")
-  month' <- (parseMonth <$> getRawField (prefix ++ "month")) <|> return ""
+  month' <- (parseMonth
+              <$> getRawField (prefix ++ "month")) <|> return ""
   day' <- getRawField (prefix ++ "day") <|> return mempty
   endyear' <- fixLeadingDash <$> getRawField (prefix ++ "endyear") <|> return ""
-  endmonth' <- getRawField (prefix ++ "endmonth") <|> return ""
+  endmonth' <- (parseMonth <$> getRawField (prefix ++ "endmonth")) <|> return ""
   endday' <- getRawField (prefix ++ "endday") <|> return ""
   let start' = RefDate { year   = Literal $ if isNumber year' then year' else ""
                        , month  = Literal $ month'
@@ -1195,11 +1212,11 @@ ordinalize locale n =
           pad0 s   = s
           terms = localeTerms locale
 
-itemToReference :: Lang -> Locale -> Bool -> Item -> Maybe Reference
-itemToReference lang locale bibtex = bib $ do
+itemToReference :: Lang -> Locale -> Bool -> Bool -> Item -> Maybe Reference
+itemToReference lang locale bibtex caseTransform = bib $ do
   modify $ \st -> st{ localeLanguage = lang,
                       untitlecase = case lang of
-                                         Lang "en" _ -> True
+                                         Lang "en" _ -> caseTransform
                                          _           -> False }
   id' <- asks identifier
   et <- asks entryType
@@ -1323,7 +1340,7 @@ itemToReference lang locale bibtex = bib $ do
   let la = case splitWhen (== '-') hyphenation' of
                       (x:_) -> x
                       []    -> mempty
-  modify $ \s -> s{ untitlecase = la == "en" }
+  modify $ \s -> s{ untitlecase = caseTransform && la == "en" }
 
   title' <- (guard isPeriodical >> getTitle "issuetitle")
             <|> (guard hasMaintitle >> guard (not isChapterlike) >> getTitle "maintitle")
