@@ -48,9 +48,9 @@ readBiblioFile f
     = case getExt f of
         ".json"     -> BL.readFile f >>= either error return . eitherDecode
         ".yaml"     -> UTF8.readFile f >>= either error return . readYamlBib
-        ".bib"      -> readBibtexInput False f
-        ".bibtex"   -> readBibtexInput True f
-        ".biblatex" -> readBibtexInput False f
+        ".bib"      -> readBibtex False True f
+        ".bibtex"   -> readBibtex True True f
+        ".biblatex" -> readBibtex False True f
 #ifdef USE_BIBUTILS
         ".mods"     -> readBiblioFile' f mods_in
         ".ris"      -> readBiblioFile' f ris_in
@@ -62,7 +62,7 @@ readBiblioFile f
         _           -> error $ "citeproc: the format of the bibliographic database could not be recognized\n" ++
                               "using the file extension."
 #else
-        _           -> error $ "citeproc: Bibliography format not supported.\n" ++
+        _           -> error $ "citeproc: Bibliography format not supported.\n"
 #endif
 
 data BibFormat
@@ -84,8 +84,8 @@ readBiblioString :: BibFormat -> String -> IO [Reference]
 readBiblioString b s
     | Json      <- b = either error return $ eitherDecode $ UTF8.fromStringLazy s
     | Yaml      <- b = either error return $ readYamlBib s
-    | Bibtex    <- b = readBibtexInputString True s
-    | BibLatex  <- b = readBibtexInputString False s
+    | Bibtex    <- b = readBibtexString True True s
+    | BibLatex  <- b = readBibtexString False True s
 #ifdef USE_BIBUTILS
     | Ris       <- b = go ris_in
     | Endnote   <- b = go endnote_in
@@ -107,7 +107,7 @@ readBiblioString b s
 #ifdef USE_BIBUTILS
 readBiblioFile' :: FilePath -> BiblioIn -> IO [Reference]
 readBiblioFile' fin bin
-    | bin == biblatex_in = readBibtexInput False fin
+    | bin == biblatex_in = readBibtex False True fin
     | otherwise      = E.handle handleBibfileError
                        $ withTempDir "citeproc"
                        $ \tdir -> do
@@ -121,7 +121,7 @@ readBiblioFile' fin bin
                             _ <- bibl_write param bibl tfile
                             bibl_free bibl
                             bibl_freeparams param
-                            refs <- readBibtexInput True tfile
+                            refs <- readBibtex True False tfile
                             return $! refs
   where handleBibfileError :: E.SomeException -> IO [Reference]
         handleBibfileError e = error $ "Error reading " ++ fin ++ "\n" ++ show e
