@@ -43,6 +43,7 @@ module Text.CSL.Util
   , (&=)
   , mapping'
   , parseRomanNumeral
+  , isRange
   ) where
 import Data.Aeson
 import Data.Aeson.Types (Parser)
@@ -69,10 +70,11 @@ import qualified Debug.Trace
 import Text.Show.Pretty (ppShow)
 #endif
 
-tr' :: Show a => String -> a -> a
 #ifdef TRACE
+tr' :: Show a => String -> a -> a
 tr' note' x = Debug.Trace.trace ("=== " ++ note' ++ "\n" ++ ppShow x ++ "\n") x
 #else
+tr' :: String -> a -> a
 tr' _ x = x
 #endif
 
@@ -193,7 +195,7 @@ unTitlecase zs = evalState (caseTransform untc zs) SentenceBoundary
           case (w, st) of
                (y, NoBoundary) -> return y
                (Str (x:xs), WordBoundary) | isUpper x ->
-                 return $ Str (toLower x : xs)
+                 return $ Str (map toLower (x:xs))
                (Str (x:xs), SentenceBoundary) | isLower x ->
                  return $ Str (toUpper x : xs)
                (Span ("",[],[]) xs, _) | hasLowercaseWord xs ->
@@ -248,7 +250,7 @@ caseTransform xform = fmap reverse . foldM go [] . splitUpStr
                put WordBoundary
                return $ Space : acc
         go acc (Str [c])
-          | c `elem` "-\2013\2014\160" = do
+          | c `elem` "-/\2013\2014\160" = do
                put WordBoundary
                return $ Str [c] : acc
           | isPunctuation c = do
@@ -426,3 +428,6 @@ pRomanNumeral = do
     if total == 0
        then fail "not a roman numeral"
        else return total
+
+isRange :: String -> Bool
+isRange s = ',' `elem` s || '-' `elem` s || '\x2013' `elem` s
